<?php

namespace Drupal\drupalorg_crosssite\Form;

use Drupal\Core\Form\FormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Url;

/**
 * Class to build *.Drupal.org Search form.
 */
class DrupalOrgSearchForm extends FormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'drupalorg_search_form';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $form['query'] = [
      '#title' => t('Search'),
      '#type' => 'textfield',
      '#attributes' => [
        'placeholder' => t('What are you searching for...'),
      ],
    ];
    $form['actions']['submit'] = [
      '#type' => 'submit',
      '#value' => t('Search'),
    ];

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    // This is the path that was set in the D7 site. We have a path processor for this path so when
    // search requests happen on D10+ they go through the D10 path.
    $url = Url::fromUserInput('/search/site/' . $form_state->getValue('query'));
    $form_state->setRedirectUrl($url);
  }

}
